@@ -1,4 +1,4 @@
-#!/usr/bin/env python3.7
+#!/usr/bin/env python3
 import os
 import tempfile
 from copy import deepcopy
@@ -369,7 +369,7 @@ class TreeNode(defaultdict):  # FIXME need to factory this to allow separate tre
                 splitter = None
 
             if splitter:
-                prefix, suffix = line.split(splitter)
+                prefix, suffix = line.split(splitter, 1)
                 if 'summary>' in line:
                     pre_splitter = 'summary>'
                     pre_prefix, prefix = prefix.split(pre_splitter, 1)
@@ -659,8 +659,8 @@ def makeHtmlNodes(nodes, sgg, prefixes, local, root_iri, root):
     htmlNodes = {}
     for k, v in nodes.items():
         if ':' in k and not k.startswith('http') and not k.startswith('file'):
-            prefix, suffix = k.split(':')
-            prefix = prefix.strip('\x1b[91m')  # colors :/
+            prefix, suffix = k.split(':', 1)
+            prefix = prefix.replace('\x1b[91m', '')  # colors :/
             if sgg is not None and not suffix and k == root:  # FIXME 268
                 url = os.path.join(sgg._basePath, 'vocabulary', 'id',
                                    quote(root_iri, safe=[]))
