@@ -1,4 +1,4 @@
-#!/usr/bin/env python3.7
+#!/usr/bin/env python3
 
 # equivalent indexed as default
 # equivalent indexed in map only
@@ -140,6 +140,12 @@ class SnchFile:
         for bn in graph[s:snchn['include']:]:
             try:
                 path = aug.RepoPath(next(graph[bn:snchn.path:]))
+                if not path.exists():
+                    # XXX note that the file must exist on the file
+                    # system when this is called, the snchn:path
+                    # cannot take a path and a git ref where the path
+                    # would exist if the ref were checked out
+                    raise FileNotFoundError(path)
             except StopIteration:
                 iri = next(graph[bn:snchn.iri:])
                 for string_path in graph[iri:snchn.hasLocalPath:]:
@@ -459,7 +465,7 @@ class Sneechenator:
         #namespaces = [derp(p) for p in prefixes]  # FIXME prefix vs namespace
         rg, maybe_sneeches = self.sneechReviewGraph(source_graph, namespaces,  sneech_file, path_out)
         # TODO I think we commit here ?
-        breakpoint()
+        #breakpoint()
 
     def CONTINUE(self, path_sneech_file):
         pass
